package pkg

type RpmdbMetadata struct {
	Epoch *int `json:"epoch"`
}
